@@ -13,7 +13,6 @@
 package config
 
 import (
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"strings"
@@ -139,6 +138,10 @@ type GuiConfig struct {
 	// containers panel. "long": full words (default), "short": one or two characters,
 	// "icon": unicode emoji.
 	ContainerStatusHealthStyle string `yaml:"containerStatusHealthStyle"`
+
+	// Window border style.
+	// One of 'rounded' (default) | 'single' | 'double' | 'hidden'
+	Border string `yaml:"border"`
 }
 
 // CommandTemplatesConfig determines what commands actually get called when we
@@ -569,7 +572,7 @@ func loadUserConfig(configDir string, base *UserConfig) (*UserConfig, error) {
 		}
 	}
 
-	content, err := ioutil.ReadFile(fileName)
+	content, err := os.ReadFile(fileName)
 	if err != nil {
 		return nil, err
 	}
